@@ -8,55 +8,54 @@ import (
 	"time"
 
 	"github.com/NYTimes/gziphandler"
-	"github.com/google/wire"
 	"github.com/twitchtv/twirp"
 	"golang.org/x/xerrors"
 
-	"github.com/aquasecurity/fanal/cache"
 	"github.com/aquasecurity/trivy-db/pkg/db"
+	"github.com/aquasecurity/trivy-db/pkg/metadata"
 	dbFile "github.com/aquasecurity/trivy/pkg/db"
+	dbc "github.com/aquasecurity/trivy/pkg/db"
+	"github.com/aquasecurity/trivy/pkg/fanal/cache"
 	"github.com/aquasecurity/trivy/pkg/log"
 	"github.com/aquasecurity/trivy/pkg/utils"
 	rpcCache "github.com/aquasecurity/trivy/rpc/cache"
 	rpcScanner "github.com/aquasecurity/trivy/rpc/scanner"
 )
 
-// DBWorkerSuperSet binds the dependencies for Trivy DB worker
-var DBWorkerSuperSet = wire.NewSet(
-	dbFile.SuperSet,
-	newDBWorker,
-)
+const updateInterval = 1 * time.Hour
 
 // Server represents Trivy server
 type Server struct {
-	appVersion  string
-	addr        string
-	cacheDir    string
-	token       string
-	tokenHeader string
+	appVersion   string
+	addr         string
+	cacheDir     string
+	token        string
+	tokenHeader  string
+	dbRepository string
 }
 
 // NewServer returns an instance of Server
-func NewServer(appVersion, addr, cacheDir, token, tokenHeader string) Server {
+func NewServer(appVersion, addr, cacheDir, token, tokenHeader, dbRepository string) Server {
 	return Server{
-		appVersion:  appVersion,
-		addr:        addr,
-		cacheDir:    cacheDir,
-		token:       token,
-		tokenHeader: tokenHeader,
+		appVersion:   appVersion,
+		addr:         addr,
+		cacheDir:     cacheDir,
+		token:        token,
+		tokenHeader:  tokenHeader,
+		dbRepository: dbRepository,
 	}
 }
 
 // ListenAndServe starts Trivy server
-func (s Server) ListenAndServe(serverCache cache.Cache) error {
+func (s Server) ListenAndServe(serverCache cache.Cache, insecure bool) error {
 	requestWg := &sync.WaitGroup{}
 	dbUpdateWg := &sync.WaitGroup{}
 
 	go func() {
-		worker := initializeDBWorker(s.cacheDir, true)
+		worker := newDBWorker(dbc.NewClient(s.cacheDir, true, insecure, dbc.WithDBRepository(s.dbRepository)))
 		ctx := context.Background()
 		for {
-			time.Sleep(1 * time.Hour)
+			time.Sleep(updateInterval)
 			if err := worker.update(ctx, s.appVersion, s.cacheDir, dbUpdateWg, requestWg); err != nil {
 				log.Logger.Errorf("%+v\n", err)
 			}
@@ -124,7 +123,7 @@ func newDBWorker(dbClient dbFile.Operation) dbWorker {
 func (w dbWorker) update(ctx context.Context, appVersion, cacheDir string,
 	dbUpdateWg, requestWg *sync.WaitGroup) error {
 	log.Logger.Debug("Check for DB update...")
-	needsUpdate, err := w.dbClient.NeedsUpdate(appVersion, false, false)
+	needsUpdate, err := w.dbClient.NeedsUpdate(appVersion, false)
 	if err != nil {
 		return xerrors.Errorf("failed to check if db needs an update")
 	} else if !needsUpdate {
@@ -133,7 +132,7 @@ func (w dbWorker) update(ctx context.Context, appVersion, cacheDir string,
 
 	log.Logger.Info("Updating DB...")
 	if err = w.hotUpdate(ctx, cacheDir, dbUpdateWg, requestWg); err != nil {
-		return xerrors.Errorf("failed DB hot update")
+		return xerrors.Errorf("failed DB hot update: %w", err)
 	}
 	return nil
 }
@@ -145,7 +144,7 @@ func (w dbWorker) hotUpdate(ctx context.Context, cacheDir string, dbUpdateWg, re
 	}
 	defer os.RemoveAll(tmpDir)
 
-	if err = w.dbClient.Download(ctx, tmpDir, false); err != nil {
+	if err = w.dbClient.Download(ctx, tmpDir); err != nil {
 		return xerrors.Errorf("failed to download vulnerability DB: %w", err)
 	}
 
@@ -160,12 +159,14 @@ func (w dbWorker) hotUpdate(ctx context.Context, cacheDir string, dbUpdateWg, re
 		return xerrors.Errorf("failed to close DB: %w", err)
 	}
 
+	// Copy trivy.db
 	if _, err = utils.CopyFile(db.Path(tmpDir), db.Path(cacheDir)); err != nil {
 		return xerrors.Errorf("failed to copy the database file: %w", err)
 	}
 
-	if err = w.dbClient.UpdateMetadata(cacheDir); err != nil {
-		return xerrors.Errorf("unable to update database metadata: %w", err)
+	// Copy metadata.json
+	if _, err = utils.CopyFile(metadata.Path(tmpDir), metadata.Path(cacheDir)); err != nil {
+		return xerrors.Errorf("failed to copy the metadata file: %w", err)
 	}
 
 	log.Logger.Info("Reopening DB...")
